pandas.Series.cast
==================

.. method:: pandas.Series.cast(*args, **kwargs) -> pandas.Series:

    An attached version of :func:`cast` that allows users to omit the ``data``
    argument.

    This method is defined for every type.
